################
storj-python-sdk
################

|pypi|_ |Build|_ |CodeHealth|_ |Coverage|_ |Requirements|_ |Documentation|_

|License|_ |Project|_

A Python SDK for the Storj API.


============
Installation
============

::

    pip install storj


.. |pypi| image:: https://img.shields.io/pypi/v/storj.svg
.. _pypi: https://pypi.python.org/pypi/storj/

.. |Build| image:: https://travis-ci.org/Storj/storj-python-sdk.svg?branch=master
.. _Build: https://travis-ci.org/Storj/storj-python-sdk

.. |CodeHealth| image:: https://landscape.io/github/steenzout/python-storj/master/landscape.svg?style=flat
.. _CodeHealth: https://landscape.io/github/steenzout/python-storj

.. |Coverage| image:: https://coveralls.io/repos/github/Storj/storj-python-sdk/badge.svg?branch=master
.. _Coverage: https://coveralls.io/r/Storj/storj-python-sdk

.. |Requirements| image:: https://requires.io/github/steenzout/python-storj/requirements.svg?branch=master
.. _Requirements: https://requires.io/github/steenzout/python-storj/requirements/?branch=master

.. |Documentation| image:: https://readthedocs.org/projects/storj-python-sdk/badge/?version=master
.. _Documentation: https://storj-python-sdk.readthedocs.io/en/latest/?badge=master

.. |License| image:: https://img.shields.io/badge/license-MIT-blue.svg?style=flat
.. _License: https://raw.githubusercontent.com/Storj/storj-python-sdk/master/LICENSE

.. |Project| image:: https://www.openhub.net/p/python-storj-sdk/widgets/project_thin_badge.gif
.. _Project: https://www.openhub.net/p/python-storj-sdk
